package com.mycompany.commerce.order.commands;

/*
 *-----------------------------------------------------------------
 * IBM Confidential
 *
 * OCO Source Materials
 *
 * WebSphere Commerce
 *
 * (C) Copyright IBM Corp. 2010
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has
 * been deposited with the U.S. Copyright Office.
 *-----------------------------------------------------------------
 */

import java.util.Map;

import com.ibm.commerce.datatype.TypedProperty;
import com.ibm.commerce.exception.ECApplicationException;
import com.ibm.commerce.exception.ECException;
import com.ibm.commerce.foundation.common.exception.ApplicationError;
import com.ibm.commerce.foundation.common.util.logging.LoggingHelper;
import com.ibm.commerce.order.commands.ServiceProviderProcessRecurringOrderCmdImpl;
import com.ibm.commerce.order.utils.ServiceProviderOrderConstants;
import com.ibm.commerce.subscription.facade.client.SubscriptionException;
import com.mycompany.commerce.order.facade.ServiceProviderOrderFacadeConstantsExt;
import com.mycompany.commerce.subscription.facade.SubscriptionFacadeConstantsExt;
import com.mycompany.commerce.subscription.facade.client.SubscriptionFacadeClientExt;

/**
 * This class extends the <code>ServiceProviderProcessRecurringOrderCmdImpl</code> class
 * to pass additional parameters to Subscription manager for a recurring order.
 * @see {@link ServiceProviderProcessRecurringOrderCmdImpl}
 */

public class ServiceProviderProcessRecurringOrderCmdExtImpl extends
	ServiceProviderProcessRecurringOrderCmdImpl {
	
	private static final String CLASSNAME = "com.ibm.commerce.order.commands.ServiceProviderProcessRecurringOrderCmdExtImpl";
	
	private static final java.util.logging.Logger LOGGER = LoggingHelper.getLogger(ServiceProviderProcessRecurringOrderCmdImpl.class);
	
	/**
	 * This method is used to additionally pass the scheduleType and dayOfMonth
	 * parameters to the subscription manager for a recurring order.
	 * @see {@link ServiceProviderProcessRecurringOrderCmdImpl#generateSubscriptionManagerParameter()}
	 * @throws ECException
	 */
	
	protected Map generateSubscriptionManagerParameter() throws ECException {
		
		final String METHODNAME = "generateSubscriptionManagerParameter()";
		
		if (LoggingHelper.isEntryExitTraceEnabled(LOGGER)) {
			LOGGER.entering(CLASSNAME, METHODNAME);
		}
		
		Map parameters = super.generateSubscriptionManagerParameter();
		
		Map fulfillParameters = (Map)parameters.get(ServiceProviderOrderConstants.SERVICE_PROVIDER_FULFILLMENT_SCHEDULE);
		
		TypedProperty requestProperties = getCommandContext().getRequestProperties();
		
		String scheduleType = requestProperties.getString(ServiceProviderOrderFacadeConstantsExt.SCHEDULE_TYPE, null);
		
		String dayOfMonth = requestProperties.getString(ServiceProviderOrderFacadeConstantsExt.DAY_OF_MONTH, null);
		
	    if(scheduleType!=null){
	    	fulfillParameters.put(SubscriptionFacadeConstantsExt.SCHEDULE_TYPE, scheduleType);
	    }
	    
	    if(dayOfMonth != null){
	    	fulfillParameters.put(SubscriptionFacadeConstantsExt.DAY_OF_MONTH, dayOfMonth);
	    }
	    
		if (LoggingHelper.isEntryExitTraceEnabled(LOGGER)) {
			LOGGER.exiting(CLASSNAME, METHODNAME);
		}
		
		return parameters;
	}
	
	/**
	 * This invokes the <code>createRecurringOrder</code>
	 * method in the <code>SubscriptionFacadeClientExt</code>.
	 * @see {@link ServiceProviderProcessRecurringOrderCmdImpl#callSubscriptionManager()}
	 */
	protected void callSubscriptionManager() throws ECException{

		final String METHODNAME = "callSubscriptionManager()";
		
		if (LoggingHelper.isEntryExitTraceEnabled(LOGGER)) {
			LOGGER.entering(CLASSNAME, METHODNAME);
		}
		
		SubscriptionFacadeClientExt subClient = new SubscriptionFacadeClientExt();
		Map parameters = generateSubscriptionManagerParameter();
		
	    try {
	    	subClient.createRecurringOrder(parameters);
	    } catch (SubscriptionException e) {	    	
	    	throw new ECApplicationException((ApplicationError)e.getClientErrors().get(0));	
	    }
	    
		if (LoggingHelper.isEntryExitTraceEnabled(LOGGER)) {
			LOGGER.exiting(CLASSNAME, METHODNAME);
		}
		
	}
}
