package com.mycompany.commerce.order.facade.client;

/*
 *-----------------------------------------------------------------
 * IBM Confidential
 *
 * OCO Source Materials
 *
 * WebSphere Commerce
 *
 * (C) Copyright IBM Corp. 2010
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has
 * been deposited with the U.S. Copyright Office.
 *-----------------------------------------------------------------
 */

import java.util.Map;
import java.util.logging.Logger;

import com.ibm.commerce.foundation.common.datatypes.SubscriptionInfoType;
import com.ibm.commerce.foundation.common.datatypes.UserDataType;
import com.ibm.commerce.foundation.common.util.logging.LoggingHelper;
import com.ibm.commerce.order.facade.client.OrderException;
import com.ibm.commerce.order.facade.client.ServiceProviderOrderFacadeClient;
import com.ibm.commerce.order.facade.datatypes.OrderType;
import com.mycompany.commerce.order.facade.ServiceProviderOrderFacadeConstantsExt;

/**
 * This class extends the ServiceProviderOrderFacadeClient to additionally accept the 
 * scheduleType and dayOfMonth parameters from the store front.
 * @see {@link ServiceProviderOrderFacadeClient}
 */

public class ServiceProviderOrderFacadeClientExt extends ServiceProviderOrderFacadeClient {
		
    private static final String CLASSNAME = ServiceProviderOrderFacadeClientExt.class.getName();
    
    private static final Logger LOGGER = LoggingHelper.getLogger(ServiceProviderOrderFacadeClientExt.class);
    
    /**
     * This method is used to additionally accept the scheduleType and dayOfMonth parameters
     * from the store front.
     * These parameters will then be populated as user data fields in the subscriptionInfo.
	 * @see {@link ServiceProviderOrderFacadeClient#prepareOrderTypeForRecurringOrder(Map parameters)}
     */
    
	protected OrderType prepareOrderTypeForRecurringOrder(Map parameters) throws OrderException {
		
		final String METHODNAME = "prepareOrderTypeForRecurringOrder(Map parameters)";
		
		if (LoggingHelper.isEntryExitTraceEnabled(LOGGER)) {
			LOGGER.entering(CLASSNAME, METHODNAME);
		}
		
		OrderType order = super.prepareOrderTypeForRecurringOrder(parameters);
		
		UserDataType userData = getCommerceFoundationFactory().createUserDataType();
		
		SubscriptionInfoType subscriptionInfo = order.getSubscriptionInfo();
		
		subscriptionInfo.setUserData(userData);
		
        String[] schType = resolveParameter(parameters, ServiceProviderOrderFacadeConstantsExt.SCHEDULE_TYPE);
        if(schType != null && schType.length > 0){
        	if(schType[0] != null){
	    		userData.getUserDataField().put(ServiceProviderOrderFacadeConstantsExt.SCHEDULE_TYPE,schType[0]);
        	}
        }
        
		String[] dayOfMonth = resolveParameter(parameters, ServiceProviderOrderFacadeConstantsExt.DAY_OF_MONTH);
		if(dayOfMonth != null && dayOfMonth.length > 0){
			if(dayOfMonth[0] != null){
				userData.getUserDataField().put(ServiceProviderOrderFacadeConstantsExt.DAY_OF_MONTH, dayOfMonth[0]);
			}
		}
		
		if (LoggingHelper.isEntryExitTraceEnabled(LOGGER)) {
			LOGGER.exiting(CLASSNAME, METHODNAME);
		}
		
		return order;
	}
}
