package com.mycompany.commerce.subscription.facade.client;

/*
 *-----------------------------------------------------------------
 * IBM Confidential
 *
 * OCO Source Materials
 *
 * WebSphere Commerce
 *
 * (C) Copyright IBM Corp. 2010
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has
 * been deposited with the U.S. Copyright Office.
 *-----------------------------------------------------------------
 */

import java.util.Map;

import com.ibm.commerce.foundation.common.datatypes.ScheduleInfoType;
import com.ibm.commerce.foundation.common.datatypes.UserDataType;
import com.ibm.commerce.foundation.common.util.logging.LoggingHelper;
import com.ibm.commerce.subscription.facade.client.SubscriptionException;
import com.ibm.commerce.subscription.facade.client.SubscriptionFacadeClient;
import com.mycompany.commerce.subscription.facade.SubscriptionFacadeConstantsExt;

/**
 * This class extends the SubscriptionFacadeClient class to additionally
 * populate the user data fields in the subscription noun.
 * @see {@link SubscriptionFacadeClient}
 */

public class SubscriptionFacadeClientExt extends SubscriptionFacadeClient {
	
	/**
	 * IBM Copyright notice field.
	 */
	public static final String COPYRIGHT = com.ibm.commerce.copyright.IBMCopyright.SHORT_COPYRIGHT;

	private static final String CLASSNAME = SubscriptionFacadeClientExt.class.getName();
	
	private static final java.util.logging.Logger LOGGER = LoggingHelper.getLogger(SubscriptionFacadeClientExt.class);	
	
	/**
	 * This method is used to additionally build the user data for the fulfillment schedule.
	 * @param inputParameters
	 *            A map of parameters containing the fulfillment schedule
	 *            information.
	 * @param isRecurring
	 *            Boolean to indicate if the instance is being built for a
	 *            recurring order or a subscription.
	 * @param actionName
	 *            The action name for which the object is being built.
	 * @return An instance of the <code>ScheduleInfoType</code>
	 * @throws SubscriptionException
	 *             When the operation is not successful.
	 * @see {@link SubscriptionFacadeClient#buildFulfillmentSchedule(Map, Boolean, String)}
	 * @see {@link SubscriptionFacadeClientExt#buildUserData(Map)}
	 */
	
	protected ScheduleInfoType buildFulfillmentSchedule(Map inputParameters, Boolean isRecurring, String actionName) throws SubscriptionException{
		final String METHODNAME = "buildFulfillmentSchedule(Map, isRecurring, actionName)";
		
		if (LoggingHelper.isEntryExitTraceEnabled(LOGGER)) {
			LOGGER.entering(CLASSNAME, METHODNAME, new Object[] {
					inputParameters, isRecurring, actionName });
		}
		
		ScheduleInfoType fulfillmentSchedule = super.buildFulfillmentSchedule(inputParameters, isRecurring, actionName);
		
		fulfillmentSchedule.setUserData(buildUserData(inputParameters));
		
		if(LoggingHelper.isEntryExitTraceEnabled(LOGGER)){
			LOGGER.exiting(CLASSNAME, METHODNAME);
		}
		
		return fulfillmentSchedule;
	}
	
	/**
	 * This method is used to populate the user data fields in the subscription noun. 
	 * @param inputParameters The map containing the input.
	 * @return The constructed <code>UserDataType</code> object.
	 * @throws SubscriptionException
	 */
	protected UserDataType buildUserData(Map inputParameters) throws SubscriptionException {
		
		final String METHODNAME = "buildUserData";
		
		if (LoggingHelper.isEntryExitTraceEnabled(LOGGER)) {
			LOGGER.entering(CLASSNAME, METHODNAME);
		}
		
		UserDataType userData = getCommerceFoundationFactory().createUserDataType();
		
		String[] scheduleType = resolveParameter(inputParameters,SubscriptionFacadeConstantsExt.SCHEDULE_TYPE);
		
		if(scheduleType != null && scheduleType.length > 0){
			if(scheduleType[0] != null){
				userData.getUserDataField().put(SubscriptionFacadeConstantsExt.SCHEDULE_TYPE,scheduleType[0]);
			}
		}
		
		String[] dayOfMonth = resolveParameter(inputParameters,SubscriptionFacadeConstantsExt.DAY_OF_MONTH);
		
		if(dayOfMonth != null && dayOfMonth.length > 0){
			if(dayOfMonth[0] != null){
				userData.getUserDataField().put(SubscriptionFacadeConstantsExt.DAY_OF_MONTH, dayOfMonth[0]);
			}
		}
		
		if (LoggingHelper.isEntryExitTraceEnabled(LOGGER)) {
			LOGGER.exiting(CLASSNAME, METHODNAME);
		}
		
		return userData;
		
	}
}
