package com.mycompany.commerce.subscription.scheduler.actions;

/*
 *-----------------------------------------------------------------
 * IBM Confidential
 *
 * OCO Source Materials
 *
 * WebSphere Commerce
 *
 * (C) Copyright IBM Corp. 2010
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has
 * been deposited with the U.S. Copyright Office.
 *-----------------------------------------------------------------
 */

import com.ibm.commerce.foundation.common.datatypes.ScheduleInfoType;
import com.ibm.commerce.foundation.common.datatypes.UserDataType;
import com.ibm.commerce.foundation.logging.LoggingHelper;
import com.ibm.commerce.subscription.facade.server.entity.datatypes.Subscription;
import com.ibm.commerce.subscription.scheduler.actions.SubscriptionCreateChildOrderSchedulerCmdImpl;
import com.mycompany.commerce.subscription.facade.SubscriptionFacadeConstantsExt;
import com.mycompany.commerce.subscription.facade.server.entity.datatypes.MyCompanySubscription;
import com.mycompany.commerce.subscription.facade.server.helpers.SubscriptionServerConstantsExt;

/**
 * This class extends SubscriptionCreateChildOrderSchedulerCmdImpl. 
 * This class will check the scheduler type to be used for creating the child order.
 * @see {@link SubscriptionCreateChildOrderSchedulerCmdImpl} 
 */
public class SubscriptionCreateChildOrderSchedulerCmdExtImpl extends SubscriptionCreateChildOrderSchedulerCmdImpl{
	
	private static final String CLASSNAME = SubscriptionCreateChildOrderSchedulerCmdExtImpl.class.getName();
	
	private static final java.util.logging.Logger LOGGER = LoggingHelper.getLogger(SubscriptionCreateChildOrderSchedulerCmdExtImpl.class);
	
	/**
	 * This method builds the fulfillment schedule to compute the next occurrence for the given schedule.
	 * The fulfillment schedule also includes scheduleType and dayOfMonth, values retrieved from custom table XSUBSCRSCHTYPE.
	 * @param subscription Subscription object
	 * @return fulfillment Schedule object
	 */
	protected ScheduleInfoType buildScheduleInfo(Subscription subscription){
		final String METHODNAME = "buildScheduleInfo";
		if(LoggingHelper.isEntryExitTraceEnabled(LOGGER)){
			LOGGER.entering(CLASSNAME, METHODNAME);
		}
		ScheduleInfoType fulfillmentSchedule = super.buildScheduleInfo(subscription);
		 
		String scheduleName = null;
		String dayOfMonth = null;
		
		MyCompanySubscription myCompanySubscription = (MyCompanySubscription) subscription;
		
		if(myCompanySubscription.getXsubscrschtypeForSubscription() != null && myCompanySubscription.getXsubscrschtypeForSubscription().getSchtype() != null){
			
			dayOfMonth = String.valueOf(myCompanySubscription.getXsubscrschtypeForSubscription().getDayofmonth());
			scheduleName = String.valueOf(myCompanySubscription.getXsubscrschtypeForSubscription().getSchtype());
			
			UserDataType userData = getCommerceFoundationFactory().createUserDataType();
			userData.getUserDataField().put(SubscriptionFacadeConstantsExt.SCHEDULE_TYPE, scheduleName);
			userData.getUserDataField().put(SubscriptionFacadeConstantsExt.DAY_OF_MONTH,dayOfMonth);
			fulfillmentSchedule.setUserData(userData);
		}	
		
		if(LoggingHelper.isEntryExitTraceEnabled(LOGGER)){
				LOGGER.exiting(CLASSNAME, METHODNAME,fulfillmentSchedule);
		}
		return fulfillmentSchedule;
	}
	
	/**
	 * This method will return the scheduler type which will be used to create the instance of <code>ScheduleEvaluateCmd</code>
	 * @return Scheduler type.
	 */
	protected String getSchedulerType(ScheduleInfoType fulfillmentSchedule){
		
		final String METHODNAME = "getSchedulerType(ScheduleInfoType)";
		
		if (LoggingHelper.isEntryExitTraceEnabled(LOGGER)) {
			LOGGER.entering(CLASSNAME, METHODNAME);
		}
		
		String scheduleName = super.getSchedulerType(fulfillmentSchedule);
		
		if (fulfillmentSchedule.getUserData() != null
				&& fulfillmentSchedule.getUserData().getUserDataField() != null
				&& fulfillmentSchedule.getUserData().getUserDataField().get(
						SubscriptionFacadeConstantsExt.SCHEDULE_TYPE) != null) {
				
			scheduleName = SubscriptionServerConstantsExt.DAY_OF_MONTH_SCHEDULE_TYPE;

		}
		
		if (LoggingHelper.isEntryExitTraceEnabled(LOGGER)) {
			LOGGER.exiting(CLASSNAME, METHODNAME, scheduleName);
		}
		
		return scheduleName;
	}
}
